@@ -166,7 +166,7 @@ data = {'cmd': [['cmd','hostname'],
                 ['cmd_raw','export HELLO=hello'],
                 ['cmd','echo $HELLO'],
                 ['cmd','pwd'],
-                ['cmd','sudo aws ec2 describe-instances']]}
+                ['cmd','aws ec2 describe-instances']]}
 headers = {'Content-Type': 'application/json','Authorization': bearer }
 url     = 'http://localhost/cmd'
 headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
@@ -198,7 +198,7 @@ time.sleep( 3 )
 gid      = elem['SecurityGroups'][0]['GroupId']
 sid      = elem['SubnetId']
 headers  = {'Content-Type': 'application/json','Authorization': bearer }
-dsg      = 'sudo aws ec2 describe-security-groups'
+dsg      = 'aws ec2 describe-security-groups'
 data     = {'cmd':[['cmd',dsg]]};
 headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
 result = json.loads(content)
@@ -216,10 +216,10 @@ for inst in result['SecurityGroups']:
       cidr      = ''
    if gid == inst['GroupId']:
       break
-new_sg   = 'sudo aws ec2 create-security-group --group-name ' + \
+new_sg   = 'aws ec2 create-security-group --group-name ' + \
            'DockerSecurityGroup --description ' + \
            '"Docker.com Security Group" 2>&1';
-ingress  = 'sudo aws ec2 authorize-security-group-ingress ' + \
+ingress  = 'aws ec2 authorize-security-group-ingress ' + \
            '--group-name DockerSecurityGroup --protocol tcp ' + \
            '--port 22 --cidr ' + cidr + ' 2>&1'
 
@@ -260,9 +260,9 @@ mvcre=credentials_file
 if re.search(' ',args.pem_file):
     mvcre="'"+mvcre+"'"
     
-data = {'cmd': [['cmd','mv -vf /tmp/'+mvpem+
+data = {'cmd': [['cmd','sudo mv -vf /tmp/'+mvpem+
                  ' '+homedir+'/FullAutoAPI'],
-                ['cmd','mv -vf /tmp/'+mvcre+
+                ['cmd','sudo mv -vf /tmp/'+mvcre+
                  ' '+homedir+'/FullAutoAPI'],
                 ['cwd',homedir+'/FullAutoAPI'],
                 ['cmd','chmod -v 400 '+mvpem],
@@ -274,7 +274,7 @@ result = json.loads(result['result'])
 from pprint import pprint
 sec_group_id=''
 if re.search('already exists for VPC',result[4][0]):
-   get_sec='sudo aws ec2 describe-security-groups --group-names DockerSecurityGroup'
+   get_sec='aws ec2 describe-security-groups --group-names DockerSecurityGroup'
    data = {'cmd': [['cmd',get_sec]]}
    time.sleep( 1 )
    headerz, content = http.request(url, "POST", body=dumps(data), \
@@ -296,7 +296,7 @@ result = json.loads(content)
 result = json.loads(result['result'])
 region=re.search(': "(.+)"',result[0][0]).group(1)
 time.sleep(1)
-get_inst = 'sudo aws ec2 describe-images --owners self amazon --filters "Name=root-device-type,Values=ebs" "Name=virtualization-type,Values=hvm" "Name=architecture,Values=x86_64" "Name=block-device-mapping.volume-size,Values=8" "Name=block-device-mapping.volume-type,Values=gp2" "Name=state,Values=available" --region='+region
+get_inst = 'aws ec2 describe-images --owners self amazon --filters "Name=root-device-type,Values=ebs" "Name=virtualization-type,Values=hvm" "Name=architecture,Values=x86_64" "Name=block-device-mapping.volume-size,Values=8" "Name=block-device-mapping.volume-type,Values=gp2" "Name=state,Values=available" --region='+region
 data = {'cmd': [['cmd',get_inst]]}
 headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
 result = json.loads(content)
@@ -305,7 +305,7 @@ result = json.loads(result[0][0])
 imagid = result['Images'][0]['ImageId']
 keynam = re.sub(r' [(]\d+[)]','',args.pem_file)
 keynam = re.sub(r'\.pem$','',keynam)
-new_inst = 'sudo aws ec2 run-instances --image-id '+imagid+' --count=1 ' + \
+new_inst = 'aws ec2 run-instances --image-id '+imagid+' --count=1 ' + \
            '--key-name ' + keynam + ' ' + \
            '--instance-type=t2.micro --security-group-ids ' + \
            sec_group_id + ' --subnet-id ' + sid
@@ -319,7 +319,7 @@ instance_id=result['Instances'][0]['InstanceId']
 loop = 1
 while loop == 1: # This creates an infinite loop
    time.sleep( 1 )
-   data = {'cmd': [['cmd','sudo aws ec2 describe-instances --instance-ids '+instance_id+' 2>&1']]};
+   data = {'cmd': [['cmd','aws ec2 describe-instances --instance-ids '+instance_id+' 2>&1']]};
    headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
    result = json.loads(content)
    result = json.loads(result['result'])
